@@ -34,112 +34,112 @@ static struct {
 	const char *glyph;
 	const char *c;
 } glyph_char[] = {
-	{"adieresis",  ""}, 
-	{"Adieresis",  ""}, 
-	{"odieresis",  ""}, 
-	{"Odieresis",  ""}, 
-	{"udieresis",  ""}, 
-	{"Udieresis",  ""}, 
-	{"germandbls", ""}, 
+	{"adieresis",  "\xE4"}, 
+	{"Adieresis",  "\xC4"}, 
+	{"odieresis",  "\xF6"}, 
+	{"Odieresis",  "\xD6"}, 
+	{"udieresis",  "\xFC"}, 
+	{"Udieresis",  "\xDC"}, 
+	{"germandbls", "\xDF"}, 
 	{"parenleft",  "("}, 
 	{"parenright", ")"}, 
 	{"percent",    "%"}, 
 	{"backslash",  "\\"}, 
-	{"exclamdown", ""},
-	{"cent",       ""},
-	{"sterling",   ""},
-	{"currency",   ""},
-	{"yen",        ""},
-	{"brokenbar",  ""},
-	{"section",    ""},
-	{"diaeresis",  ""},
-	{"copyright",  ""},
-	{"ordfeminine",""},
-	{"guillemotleft",""},
-	{"notsign",    ""},
-	{"hyphen",     ""},
-	{"registered", ""},
-	{"macron",     ""},
-	{"degree",     ""},
-	{"plusminus",  ""},
-	{"twosuperior",""},
-	{"threesuperior",""},
-	{"acute",      ""},
-	{"mu",         ""},
-	{"paragraph",  ""},
-	{"periodcentered",""},
-	{"cedilla",    ""},
-	{"onesuperior",""},
-	{"masculine",  ""},
-	{"guillemotright",""},
-	{"onequarter", ""},
-	{"onehalf",    ""},
-	{"threequarters",""},
-	{"questiondown",""},
-	{"Agrave",      ""},
-	{"Aacute",      ""},
-	{"Acircumflex", ""},
-	{"Atilde",      ""},
-	{"Adiaeresis",  ""},
-	{"Aring",       ""},
-	{"AE",          ""},
-	{"Ccedilla",    ""},
-	{"Egrave",      ""},
-	{"Eacute",      ""},
-	{"Ecircumflex", ""},
-	{"Ediaeresis",  ""},
-	{"Igrave",      ""},
-	{"Iacute",      ""},
-	{"Icircumflex", ""},
-	{"Idiaeresis",  ""},
-	{"ETH",         ""},
-	{"Ntilde",      ""},
-	{"Ograve",      ""},
-	{"Oacute",      ""},
-	{"Ocircumflex", ""},
-	{"Otilde",      ""},
-	{"Odiaeresis",  ""},
-	{"multiply",    ""},
-	{"Ooblique",    ""},
-	{"Ugrave",      ""},
-	{"Uacute",      ""},
-	{"Ucircumflex", ""},
-	{"Udiaeresis",  ""},
-	{"Yacute",      ""},
-	{"THORN",       ""},
-	{"ssharp",      ""},
-	{"agrave",      ""},
-	{"aacute",      ""},
-	{"acircumflex", ""},
-	{"atilde",      ""},
-	{"adiaeresis",  ""},
-	{"aring",       ""},
-	{"ae",          ""},
-	{"ccedilla",    ""},
-	{"egrave",      ""},
-	{"eacute",      ""},
-	{"ecircumflex", ""},
-	{"ediaeresis",  ""},
-	{"igrave",      ""},
-	{"iacute",      ""},
-	{"icircumflex", ""},
-	{"idiaeresis",  ""},
-	{"eth",         ""},
-	{"ntilde",      ""},
-	{"ograve",      ""},
-	{"oacute",      ""},
-	{"ocircumflex", ""},
-	{"otilde",      ""},
-	{"odiaeresis",  ""},
-	{"division",    ""},
-	{"oslash",      ""},
-	{"ugrave",      ""},
-	{"uacute",      ""},
-	{"ucircumflex", ""},
-	{"udiaeresis",  ""},
-	{"yacute",      ""},
-	{"thorn",       ""},
-	{"ydiaeresis",  ""},
+	{"exclamdown", "\xA1"},
+	{"cent",       "\xA2"},
+	{"sterling",   "\xA3"},
+	{"currency",   "\xA4"},
+	{"yen",        "\xA5"},
+	{"brokenbar",  "\xA6"},
+	{"section",    "\xA7"},
+	{"diaeresis",  "\xA8"},
+	{"copyright",  "\xA9"},
+	{"ordfeminine","\xAA"},
+	{"guillemotleft","\xAB"},
+	{"notsign",    "\xAC"},
+	{"hyphen",     "\xAD"},
+	{"registered", "\xAE"},
+	{"macron",     "\xAF"},
+	{"degree",     "\xB0"},
+	{"plusminus",  "\xB1"},
+	{"twosuperior","\xB2"},
+	{"threesuperior","\xB3"},
+	{"acute",      "\xB4"},
+	{"mu",         "\xB5"},
+	{"paragraph",  "\xB6"},
+	{"periodcentered","\xB7"},
+	{"cedilla",    "\xB8"},
+	{"onesuperior","\xB9"},
+	{"masculine",  "\xBA"},
+	{"guillemotright","\xBB"},
+	{"onequarter", "\xBC"},
+	{"onehalf",    "\xBD"},
+	{"threequarters","\xBE"},
+	{"questiondown","\xBF"},
+	{"Agrave",      "\xC0"},
+	{"Aacute",      "\xC1"},
+	{"Acircumflex", "\xC2"},
+	{"Atilde",      "\xC3"},
+	{"Adiaeresis",  "\xC4"},
+	{"Aring",       "\xC5"},
+	{"AE",          "\xC6"},
+	{"Ccedilla",    "\xC7"},
+	{"Egrave",      "\xC8"},
+	{"Eacute",      "\xC9"},
+	{"Ecircumflex", "\xCA"},
+	{"Ediaeresis",  "\xCB"},
+	{"Igrave",      "\xCC"},
+	{"Iacute",      "\xCD"},
+	{"Icircumflex", "\xCE"},
+	{"Idiaeresis",  "\xCF"},
+	{"ETH",         "\xD0"},
+	{"Ntilde",      "\xD1"},
+	{"Ograve",      "\xD2"},
+	{"Oacute",      "\xD3"},
+	{"Ocircumflex", "\xD4"},
+	{"Otilde",      "\xD5"},
+	{"Odiaeresis",  "\xD6"},
+	{"multiply",    "\xD7"},
+	{"Ooblique",    "\xD8"},
+	{"Ugrave",      "\xD9"},
+	{"Uacute",      "\xDA"},
+	{"Ucircumflex", "\xDB"},
+	{"Udiaeresis",  "\xDC"},
+	{"Yacute",      "\xDD"},
+	{"THORN",       "\xDE"},
+	{"ssharp",      "\xDF"},
+	{"agrave",      "\xE0"},
+	{"aacute",      "\xE1"},
+	{"acircumflex", "\xE2"},
+	{"atilde",      "\xE3"},
+	{"adiaeresis",  "\xE4"},
+	{"aring",       "\xE5"},
+	{"ae",          "\xE6"},
+	{"ccedilla",    "\xE7"},
+	{"egrave",      "\xE8"},
+	{"eacute",      "\xE9"},
+	{"ecircumflex", "\xEA"},
+	{"ediaeresis",  "\xEB"},
+	{"igrave",      "\xEC"},
+	{"iacute",      "\xED"},
+	{"icircumflex", "\xEE"},
+	{"idiaeresis",  "\xEF"},
+	{"eth",         "\xF0"},
+	{"ntilde",      "\xF1"},
+	{"ograve",      "\xF2"},
+	{"oacute",      "\xF3"},
+	{"ocircumflex", "\xF4"},
+	{"otilde",      "\xF5"},
+	{"odiaeresis",  "\xF6"},
+	{"division",    "\xF7"},
+	{"oslash",      "\xF8"},
+	{"ugrave",      "\xF9"},
+	{"uacute",      "\xFA"},
+	{"ucircumflex", "\xFB"},
+	{"udiaeresis",  "\xFC"},
+	{"yacute",      "\xFD"},
+	{"thorn",       "\xFE"},
+	{"ydiaeresis",  "\xFF"},
 	{NULL, NULL}};
 
 static const char * glyph_to_char(char *glyph) {
