@@ -1,12 +1,11 @@
 //
-// Copyright 2007 Johannes Hofmann <Johannes.Hofmann@gmx.de>
+// Copyright 2006-2008 Johannes Hofmann <Johannes.Hofmann@gmx.de>
 //
 // This software may be used and distributed according to the terms
 // of the GNU General Public License, incorporated herein by reference.
 
 #include <stdio.h>
 #include <string.h>
-#include <unistd.h>
 #include <stdlib.h>
 #include <sys/types.h>
 #include <sys/wait.h>
@@ -35,24 +34,24 @@ Fl_Scroll *scroll = NULL;
 Fl_Hold_Browser *page_sel = NULL;
 
 int xev_handler(int ev) {
-	if (psed_p) {
+	if (psed_p)
 		return psed_p->handleX11(ev);
-	} else {
+	else
 		return 0;
-	}
 }
 
 void save_cb();
 
 int check_save(void) {
-	if (!psed_p->modified()) return 1;
+	if (!psed_p->modified())
+		return 1;
 
 	int r = fl_choice("The current file has not been saved.\n"
 		"Would you like to save it now?",
 		"Cancel", "Save", "Discard Changes");
 
 	if (r == 1) {
-		save_cb(); // Save the file...
+		save_cb();
 		return !psed_p->modified();
 	}
 
@@ -62,37 +61,35 @@ int check_save(void) {
 static int
 confirm_overwrite(const char *f) {
 	struct stat sb;
-	if (stat(f, &sb) == 0) {
+
+	if (stat(f, &sb) == 0)
 		return fl_choice("The file exists.\n", "Cancel", "Overwrite", NULL);
-	} else {
+	else
 		return 1;
-	}
 }
 
-char filename[256] = "";
-
+char filename[1024] = "";
 
 void page_sel_cb(Fl_Widget *w, void *) {
 	int p = page_sel->value();
-	if (p > 0) {
+	if (p > 0)
 		psed_p->load_page(page_sel->value());
-	}
 }
 
 void page_sel_fill() {
-	char buf[64];
+	char buf[128];
 	int p = psed_p->get_pages();
 
 	page_sel->clear();
 
-	if (p == 0) {
+	if (!p)
 		return;
-	}
 
-	for(int i=1; i<=p; i++) {
+	for (int i = 1; i <= p; i++) {
 		snprintf(buf, sizeof(buf), "%d", i);
 		page_sel->add(buf);
 	}
+
 	page_sel->select(psed_p->get_page());
 }
 
@@ -138,12 +135,12 @@ void open_file(char *file) {
 void open_cb() {
 	char *file;
 
-	if (!check_save()) return;
+	if (!check_save())
+		return;
 
 	file = fl_file_chooser("Open File?", "*.{ps,pdf}", filename);
-	if(file != NULL) {
+	if (file)
 		open_file(file);
-	}  
 }
 
 void export_pdf_cb() {
@@ -185,9 +182,8 @@ void export_pdf_cb() {
 
 void import_cb() {
 	char *file = fl_file_chooser("Import Overlay from File?", "*.ps", filename);
-	if(file != NULL) {
+	if (file)
 		psed_p->import(file);
-	}  
 }
 
 void first_cb() {
@@ -201,47 +197,50 @@ void next_cb() {
 }
 
 void quit_cb() {
-	if (!check_save()) return;
+	if (!check_save())
+		return;
 	delete psed_p;
 	exit(0);
 }
 
 void save_cb() {
 	char *file = fl_file_chooser("Open File?", "*.ps", filename);
-	if (file != NULL && confirm_overwrite(file)) {
+	if (file && confirm_overwrite(file))
 		psed_p->save(file);
-	}
 }
 
 void print_cb() {
-	char tmpname[256];
-	char buf[256];
-	int tmp_fd;
+	char *pref_cmd;
+	int r;
+	const char *print_cmd;
+	Fl_Preferences prefs(Fl_Preferences::USER,
+		"Johannes.HofmannATgmx.de", "flpsed");
 
-	int r = fl_choice("Print file?", "Cancel", "Print", NULL);
-	if (r != 1) {
+	prefs.get("printCommand", pref_cmd, "lpr");
+	print_cmd = fl_input("Print Command, e.g. \"lpr\" or \"psnup -2 | lpr\"", pref_cmd);
+	if (!print_cmd || print_cmd[0] == '\0')
 		return;
-	}
 
-	strncpy(tmpname, "/tmp/PSEditWidgetXXXXXX", 256);
-	tmp_fd = mkstemp(tmpname);
+	if (strcmp(print_cmd, pref_cmd))
+		prefs.set("printCommand", print_cmd);
 
-	if (tmp_fd >= 0) {
-		close(tmp_fd);
-		if (psed_p->save(tmpname) != 0) {
-			fprintf(stderr, "Failed to print file\n");
-		} else {
-			snprintf(buf, 256, "lpr %s", tmpname);
-			system(buf);
-		}
-		unlink(tmpname);
+	FILE *fp = popen(print_cmd, "w");
+
+	if (fp) {
+		signal(SIGPIPE, SIG_IGN);
+		r = psed_p->save(fp);
+		pclose(fp);
+		signal(SIGPIPE, SIG_DFL);
 	} 
+
+	if (!fp || r)
+		fprintf(stderr, "Print Command %s failed\n", print_cmd);
 }
 
 void about_cb() {
 	fl_message("flpsed -- a PostScript annotator\n"
 		"Version %s\n\n"
-		"(c) Johannes Hofmann 2004-2006\n\n"
+		"(c) Johannes Hofmann 2004-2008\n\n"
 		"PostScript is a registered trademark of Adobe Systems", VERSION);
 }
 
@@ -281,9 +280,8 @@ void property_changed_cb() {
 void size_cb(Fl_Widget *w, void *) {
 	Fl_Menu_* mw = (Fl_Menu_*)w;
 	const Fl_Menu_Item* m = mw->mvalue();
-	if (m) {
+	if (m)
 		psed_p->set_size(atoi(m->label()));
-	}
 }
 
 void color_cb(Fl_Widget *w, void *v) {
@@ -296,7 +294,9 @@ void color_cb(Fl_Widget *w, void *v) {
 	g = pc.get_g();
 	b = pc.get_b();
 
-	if (!fl_color_chooser("Text Color", r, g, b)) return;
+	if (!fl_color_chooser("Text Color", r, g, b))
+		return;
+
 	Fl_Button* button = (Fl_Button*)v;
 	pc.set(r, g, b);
 	psed_p->set_color(&pc);
@@ -473,7 +473,6 @@ int main(int argc, char** argv) {
 	my_argc = argc - optind;
 	my_argv = argv + optind;
 
-
 	if (bflag || dflag) {
 		//
 		// Batch Mode 
@@ -493,7 +492,6 @@ int main(int argc, char** argv) {
 			in_fp = stdin;
 		}
 
-
 		tmp_fd = m->load(in_fp);
 
 		if (tmp_fd == -1) {
@@ -501,17 +499,15 @@ int main(int argc, char** argv) {
 			exit(1);
 		}
 
-		if (in_fp != stdin) {
+		if (in_fp != stdin)
 			fclose(in_fp);
-		}
 
-		for(int i=0; i<tv_idx; i++) {
+		for (int i = 0; i < tv_idx; i++) {
 			m->replace_tag(tv[i].tag, tv[i].value);
 			free(tv[i].tag);
 			free(tv[i].value);
 		}
 
-
 		if (bflag) {
 			if (my_argc >= 2) {
 				out_fp = fopen(my_argv[1], "w");
@@ -525,10 +521,10 @@ int main(int argc, char** argv) {
 
 			m->save(out_fp, tmp_fd);
 
-			if (out_fp != stdout) {
+			if (out_fp != stdout)
 				fclose(out_fp);
-			}
-		} else { // dump tags
+
+		} else {
 			m->dump_tags();
 		}
 
@@ -563,7 +559,6 @@ int main(int argc, char** argv) {
 		psed_p->property_changed_callback(property_changed_cb);
 		scroll->end();
 
-
 		fl_open_display();
 		Fl::add_handler(xev_handler);
 
@@ -573,16 +568,13 @@ int main(int argc, char** argv) {
 		win->callback((Fl_Callback *)quit_cb);
 		win->show(1, argv); 
 
-
-		if (zoom_val) {
+		if (zoom_val)
 			psed_p->zoom(zoom_val);
-		}
 
-		if (my_argc >= 1) {
+		if (my_argc >= 1)
 			open_file(my_argv[0]);
-		}
 
-		for(int i=0; i<tv_idx; i++) {
+		for (int i = 0; i < tv_idx; i++) {
 			psed_p->replace_tag(tv[i].tag, tv[i].value);
 			free(tv[i].tag);
 			free(tv[i].value);
